
# Logistic regression : R code for the "sox in box" activity : part 1

# Understanding the 'distance' model
# ==================================
# In this script we build up the model relating the result to the 'distance'
#   covariate.
# Put in your own comments to explain what each command does.

library(wiqid)

# Load the data and check
# -----------------------

# Change the file name below to the name of our file:
sox <- read.csv("Sox_in_box_old.csv")

# If that doesn't work, try this
# sox <- read.csv(file.choose())

head(sox)
summary(sox)
View(sox)  # Close the View window when you are done with it.

# Build up the logistic model for distance step by step
# -----------------------------------------------------
# 1. Think of some sensible values for B0 and Bdist
B0 <- 4
Bdist <- -1
# We'll change these later to find the maximum likelihood

# 2. Calculate y on the logit scale
sox$y <- B0 + Bdist * sox$distance

# 3. Calculate p, probability of getting sock in box
sox$p <- plogis(sox$y)
View(sox) # Now has 'y' and 'p' columns

# 4. Calculate likelihood, probability of getting the result (0 or 1)
sox$llh <- ifelse(sox$result == 1, sox$p, 1 - sox$p)
View(sox)  # Compare the 'p' and 'llh' columns.

# 5. Calculate log(llh) and the total log(llh)
sox$logllh <- log(sox$llh)
sum(sox$logllh)

# Find the values of B0 and Bdist which give the maximum log(llh)
# ---------------------------------------------------------------
# Experiment with different values for the coefficients:
B0 <- 3.5
Bdist <- -0.9
sox$y <- B0 + Bdist * sox$distance
sox$p <- plogis(sox$y)
sox$llh <- ifelse(sox$result == 1, sox$p, 1 - sox$p)
sox$logllh <- log(sox$llh)
sum(sox$logllh)
# Change B0 and Bdist and run the above lines again, then compare sum(log(llh))

# When you get tired of that, use 'glm' to get the best values for B0 and Bdist
?glm
( glm.dist <- glm(result ~ distance, data=sox, family='binomial') )

B0 <- coef(glm.dist)[1]
Bdist <- coef(glm.dist)[2]
sox$y <- B0 + Bdist * sox$dist
sox$p <- plogis(sox$y)
sox$llh <- ifelse(sox$result == 1, sox$p, 1 - sox$p)
sox$logllh <- log(sox$llh)
sum(sox$logllh) # This is the highest possible value.
View(sox)

# Calculate AIC for this model
# Number of parameters is 2,
2 * 2 - 2 * sum(sox$logllh)

# Now go to the script "Sox_in_box_2_model_comparison" to see how the
#   distance model compares with others.
