
# Logistic regression : R code for the "sox in box" activity : part 2

# Comparing models
# ================
# In this script we compare different models for the sox-in-box data

library(wiqid)

# Load the data and check
# -----------------------

# Change the file name below to the name of our file:
sox <- read.csv("Sox_in_box_old.csv")

# If that doesn't work, try this
# sox <- read.csv(file.choose())

head(sox)
summary(sox)
View(sox)  # Close the View window when you are done with it.

# Run various models and compare with AIC
# =======================================

( glm.dist <- glm(result ~ distance, data=sox, family='binomial') )

( glm.hand <- glm(result ~ hand.good, data=sox, family='binomial') )

( glm.hd <- glm(result ~ distance + hand.good, data=sox, family='binomial') )

# This model (the "null model") has no covariates: what does that mean?
( glm.0 <- glm(result ~ 1, data=sox, family='binomial') )

AIC(glm.0, glm.hand, glm.dist, glm.hd)

# Could the die roll affect the result?
# -------------------------------------
( glm.D <- glm(result ~ die, data=sox, family='binomial') )
confint(glm.D)

( glm.dD <- glm(result ~ distance + die, data=sox, family='binomial') )
confint(glm.dD)

AICtable(AIC(glm.0, glm.hand, glm.dist, glm.hd, glm.D, glm.dD))

# How do we interpret the results?
# --------------------------------

( pars.hd <- coef(glm.hd) )

# What does this represent?
plogis(pars.hd['(Intercept)'] + pars.hd['distance']*1 + pars.hd['hand.good']*1)

# Calculate the predicted probability for:

# 1. Distance zero, bad hand

# 2. Distance 5m, bad hand

# 3. Distance 5m, good hand



