
# Rafflesia - stratified sampling

# Here we see how to get Bayesian credible intervals from stratified sampling.

# See Rafflesia_stratified_sampling.pdf for background information.

library(wiqid)

# The population
# ==============
set.seed(123)
truePop <- c(rpois(160,10), rpois(240,1))
(total <- sum(truePop)) # no. of Rafflesia in the population
sum(truePop[1:160])   # in the high density area...
sum(truePop[161:400]) # ...and in the low density area

# Unstratified simple random sampling:
# ====================================
x <- sample(truePop, 20)
mean(x) # estimated average number of Rafflesia per plot
mean(x) * 400 # estimated number of Rafflesia in the whole area (400 plots)

( lamU <- Bpoisson(sum(x), 20) )
plot(lamU)
totalU <- lamU$lambda * 400
postPlot(totalU)


# Stratified sampling
# ===================
n1 <- 8 # from high density area
n2 <- 12 # from low density area

x1 <- sample(truePop[1:160], n1)
x2 <- sample(truePop[161:400], n2)
mean(x1)  # average per plot in high density area...
mean(x2)  # ... and in low density area.
mean(x1) * 160 + mean(x2) * 240  # Estimated total number

( lam1 <- Bpoisson(sum(x1), n1) )
( lam2 <- Bpoisson(sum(x2), n2) )
par(mfrow = 2:1)
plot(lam1)
plot(lam2)
plot(lam1, xlim=c(0.5, 15))
plot(lam2, xlim=c(0.5, 15))
par(mfrow = c(1,1))

total8.12 <- lam1$lambda * 160 + lam2$lambda * 240
postPlot(total8.12)


# Stratified sample, more plots in high density area
n1 <- 13
n2 <- 7
x1 <- sample(truePop[1:160], n1)
x2 <- sample(truePop[161:400], n2)
mean(x1)  # average per plot in high density area...
mean(x2)  # ... and in low density area.
mean(x1) * 160 + mean(x2) * 240  # Estimated total number

( lam1 <- Bpoisson(sum(x1), n1) )
( lam2 <- Bpoisson(sum(x2), n2) )
par(mfrow = 2:1)
plot(lam1, xlim=c(0.5, 12))
plot(lam2, xlim=c(0.5, 12))
par(mfrow = c(1,1))

total13.7 <- lam1$lambda * 160 + lam2$lambda * 240
postPlot(total13.7)

